@@ -1,16 +1,9 @@
 ActiveRecord::Base.establish_connection(
   adapter: "sqlite3",
-  database: ":memory:",
+  database: ":memory:"
 )
 
-migration_class =
-  if ActiveRecord::Migration.respond_to?(:[])
-    ActiveRecord::Migration[4.2]
-  else
-    ActiveRecord::Migration
-  end
-
-class CreateSchema < migration_class
+class CreateSchema < ActiveRecord::Migration[5.0]
   def self.up
     create_table :categories, force: true do |t|
       t.string :name
