@@ -9,10 +9,10 @@ module FactoryBot
   ]
 
   def self.aliases_for(attribute)
-    aliases.map do |(pattern, replace)|
+    aliases.map { |(pattern, replace)|
       if pattern.match(attribute.to_s)
         attribute.to_s.sub(pattern, replace).to_sym
       end
-    end.compact << attribute
+    }.compact << attribute
   end
 end
