@@ -7,7 +7,7 @@ module FactoryBot
     attr_reader :name
 
     def initialize(name)
-      @name  = name
+      @name = name
       @items = ActiveSupport::HashWithIndifferentAccess.new
     end
 
@@ -21,11 +21,11 @@ module FactoryBot
 
     def find(name)
       @items.fetch(name)
-    rescue KeyError => key_error
-      raise key_error_with_custom_message(key_error)
+    rescue KeyError => e
+      raise key_error_with_custom_message(e)
     end
 
-    alias :[] :find
+    alias_method :[], :find
 
     def register(name, item)
       @items[name] = item
