@@ -9,13 +9,13 @@ module FactoryBot
       @definition = Definition.new(@name)
       proxy = FactoryBot::DefinitionProxy.new(@definition)
 
-      if block_given?
+      if block
         proxy.instance_eval(&@block)
       end
     end
 
     delegate :add_callback, :declare_attribute, :to_create, :define_trait, :constructor,
-             :callbacks, :attributes, to: :@definition
+      :callbacks, :attributes, to: :@definition
 
     def names
       [@name]
