@@ -1,6 +1,6 @@
 unless ActiveSupport::Notifications.respond_to?(:subscribed)
   module SubscribedBehavior
-    def subscribed(callback, *args, &block)
+    def subscribed(callback, *args)
       subscriber = subscribe(*args, &callback)
       yield
     ensure
@@ -12,25 +12,24 @@ unless ActiveSupport::Notifications.respond_to?(:subscribed)
 end
 
 describe "using ActiveSupport::Instrumentation to track factory interaction" do
-  let(:slow_user_factory) { FactoryBot.factory_by_name("slow_user") }
-  let(:user_factory) { FactoryBot.factory_by_name("user") }
+  let(:slow_user_factory) { FactoryBot::Internal.factory_by_name("slow_user") }
+  let(:user_factory) { FactoryBot::Internal.factory_by_name("user") }
   before do
     define_model("User", email: :string)
     FactoryBot.define do
       factory :user do
-        email "john@example.com"
+        email { "john@example.com" }
 
         factory :slow_user do
           after(:build) { Kernel.sleep(0.1) }
         end
       end
-
     end
   end
 
   it "tracks proper time of creating the record" do
     time_to_execute = 0
-    callback = ->(name, start, finish, id, payload) { time_to_execute = finish - start }
+    callback = ->(_name, start, finish, _id, _payload) { time_to_execute = finish - start }
     ActiveSupport::Notifications.subscribed(callback, "factory_bot.run_factory") do
       FactoryBot.build(:slow_user)
     end
@@ -41,7 +40,7 @@ describe "using ActiveSupport::Instrumentation to track factory interaction" do
   it "builds the correct payload" do
     tracked_invocations = {}
 
-    callback = ->(name, start, finish, id, payload) do
+    callback = ->(_name, _start, _finish, _id, payload) do
       factory_name = payload[:name]
       strategy_name = payload[:strategy]
       factory = payload[:factory]
