@@ -14,7 +14,7 @@ describe "defining methods inside FactoryBot" do
 
     expect(bad_factory_definition).to raise_error(
       FactoryBot::MethodDefinitionError,
-      /Defining methods in blocks \(trait or factory\) is not supported \(generate_name\)/,
+      /Defining methods in blocks \(trait or factory\) is not supported \(generate_name\)/
     )
   end
 end
